DataInput

Enum DataInput 

pub enum DataInput {
    Text(String),
    FilePath(String),
    Url(String),
    S3Path(String),
    Binary {
        data: Vec<u8>,
        name: String,
    },
    DataItem {
        data: Box<DataInput>,
        label: String,
        external_metadata: Option<String>,
    },
}

Variants



Text(String)

Raw text content



FilePath(String)

Local file path



Url(String)

HTTP/HTTPS URL



S3Path(String)

S3 path (s3://bucket/key) — TODO stub



Binary

In-memory binary data with a filename for MIME detection

Fields

data: Vec<u8>
name: String


DataItem

DataItem wrapper — wraps any other input with a custom label and optional metadata

Fields

label: String
external_metadata: Option<String>

Implementations

Source

impl DataInput

pub async fn process_by_chunks<F, Fut, E>(&self, callback: F) -> Result<(), E>
where F: FnMut(&[u8]) -> Fut, Fut: Future<Output = Result<(), E>>, E: From<Error>,

Process the input data by chunks, calling the provided callback for each chunk. This allows efficient streaming processing without loading entire files into memory.

Arguments
  • callback - An async callback function that receives each chunk of data
pub fn from_string(s: String) -> Self

Classify a string into the appropriate DataInput variant

pub fn classify(&self) -> &str

Get the type of this input as a string

pub fn as_str(&self) -> &str

Get the inner string value (not applicable for Binary/DataItem)