pub struct CognifyInterval {
pub time_from: CognifyTimestamp,
pub time_to: CognifyTimestamp,
}Expand description
A time range stored as a graph node of type “Interval”. Mirrors Python: cognee.modules.engine.models.Interval Field names time_from / time_to match Python exactly.
Fields
time_from: CognifyTimestamptime_to: CognifyTimestampTrait Implementations
Sourceimpl Clone for CognifyInterval
impl Clone for CognifyInterval
Sourcefn clone(&self) -> CognifyInterval
fn clone(&self) -> CognifyInterval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CognifyInterval
impl Debug for CognifyInterval
Sourceimpl<'de> Deserialize<'de> for CognifyInterval
impl<'de> Deserialize<'de> for CognifyInterval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CognifyInterval
impl JsonSchema for CognifyInterval
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CognifyInterval
impl PartialEq for CognifyInterval
Sourcefn eq(&self, other: &CognifyInterval) -> bool
fn eq(&self, other: &CognifyInterval) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CognifyInterval
impl Serialize for CognifyInterval
impl StructuralPartialEq for CognifyInterval