pub struct RawExtractedTimestamp {
pub year: u16,
pub month: u8,
pub day: u8,
pub hour: u8,
pub minute: u8,
pub second: u8,
}Expand description
LLM output schema for a timestamp. Mirrors Python task model Timestamp. All fields except year default to 1/0; the extractor computes time_at.
Fields
year: u16month: u8day: u8hour: u8minute: u8second: u8Trait Implementations
Sourceimpl Clone for RawExtractedTimestamp
impl Clone for RawExtractedTimestamp
Sourcefn clone(&self) -> RawExtractedTimestamp
fn clone(&self) -> RawExtractedTimestamp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawExtractedTimestamp
impl Debug for RawExtractedTimestamp
Sourceimpl<'de> Deserialize<'de> for RawExtractedTimestamp
impl<'de> Deserialize<'de> for RawExtractedTimestamp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RawExtractedTimestamp
impl JsonSchema for RawExtractedTimestamp
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RawExtractedTimestamp
impl RefUnwindSafe for RawExtractedTimestamp
impl Send for RawExtractedTimestamp
impl Sync for RawExtractedTimestamp
impl Unpin for RawExtractedTimestamp
impl UnsafeUnpin for RawExtractedTimestamp
impl UnwindSafe for RawExtractedTimestamp